# rs_mailer

`rs_mailer` is a really simple Python package created to send emails through SMTP servers. Nothing fancy at all, just created using standard `smtplib` and `email` packages, for use with my other Python codes.
Feel free to use this if needed. 

# License

`rs_mailer` is licensed under BSD-new license. Please check `LICENSE`.
